@@ -1737,16 +1737,16 @@ def cli(
 
                         color_print_green(" [+] Users located", "")
                         color_print_green("  ├  Users within 500m:  ", str(d_500))
-                        color_print_green("  ├  Users within 1000m: ", str(d_1000))
-                        color_print_green("  ├  Users within 2000m: ", str(d_2000))
-                        color_print_green("  ├  Users within 3000m: ", str(d_3000))
-                        color_print_green("  ├  Users within 3000m: ", str(d_4000))
-                        color_print_green("  ├  Users within 3000m: ", str(d_5000))
-                        color_print_green("  ├  Users within 3000m: ", str(d_6000))
-                        color_print_green("  ├  Users within 3000m: ", str(d_7000))
-                        color_print_green("  ├  Users within 3000m: ", str(d_8000))
-                        color_print_green("  ├  Users within 3000m: ", str(d_9000))
-                        color_print_green("  ├  Users within 3000m: ", str(d_10000))
+                        color_print_green("  ├  Users within 1,000m: ", str(d_1000))
+                        color_print_green("  ├  Users within 2,000m: ", str(d_2000))
+                        color_print_green("  ├  Users within 3,000m: ", str(d_3000))
+                        color_print_green("  ├  Users within 4,000m: ", str(d_4000))
+                        color_print_green("  ├  Users within 5,000m: ", str(d_5000))
+                        color_print_green("  ├  Users within 6,000m: ", str(d_6000))
+                        color_print_green("  ├  Users within 7,000m: ", str(d_7000))
+                        color_print_green("  ├  Users within 8,000m: ", str(d_8000))
+                        color_print_green("  ├  Users within 9,000m: ", str(d_9000))
+                        color_print_green("  ├  Users within 10,000m: ", str(d_10000))
                         color_print_green("  ├  Total users found:  ", str(total))
                         color_print_green("  └  Location list saved to: ", save_file)
 
